@@ -13,9 +13,12 @@ typedef Eo Ecore_Audio_In_Tone;
 
 
 #endif
+/** Ecore Audio tone input.
+ *
+ * @ingroup Ecore_Audio_In_Tone
+ */
 #define ECORE_AUDIO_IN_TONE_CLASS ecore_audio_in_tone_class_get()
 
-EAPI const Eo_Class *ecore_audio_in_tone_class_get(void) EINA_CONST;
-
+EWAPI const Efl_Class *ecore_audio_in_tone_class_get(void);
 
 #endif
