@@ -13,20 +13,25 @@ typedef Eo Efl_Text;
 
 
 #endif
+/** Efl text interface
+ *
+ * @ingroup Efl_Text
+ */
 #define EFL_TEXT_INTERFACE efl_text_interface_get()
 
-EAPI const Eo_Class *efl_text_interface_get(void) EINA_CONST;
+EWAPI const Efl_Class *efl_text_interface_get(void);
 
 /**
  * @brief Sets the text string to be displayed by the given text object.
  *
  * See also @ref efl_text_get.
  *
+ * @param[in] obj The object.
  * @param[in] text Text string to display on it.
  *
  * @ingroup Efl_Text
  */
-EOAPI void efl_text_set(const char *text);
+EOAPI void efl_text_set(Eo *obj, const char *text);
 
 /**
  * @brief Retrieves the text string currently being displayed by the given text
@@ -36,11 +41,12 @@ EOAPI void efl_text_set(const char *text);
  *
  * See also @ref efl_text_set.
  *
+ * @param[in] obj The object.
+ *
  * @return Text string to display on it.
  *
  * @ingroup Efl_Text
  */
-EOAPI const char *efl_text_get(void);
-
+EOAPI const char *efl_text_get(const Eo *obj);
 
 #endif
