@@ -26,7 +26,8 @@ EWAPI const Efl_Class *elm_code_widget_class_get(void);
  * only be set during construction, once the widget is created the backing code
  * object cannot be changed.
  *
- * @param[in] code Our underlying Elm_Code object
+ * @param[in] obj The object.
+ * @param[in] code Our underlying Elm.Code object
  *
  * @ingroup Elm_Code_Widget
  */
@@ -35,7 +36,9 @@ EOAPI void elm_obj_code_widget_code_set(Eo *obj, Elm_Code *code);
 /**
  * @brief Get the underlying code object we are rendering
  *
- * @return Our underlying Elm_Code object
+ * @param[in] obj The object.
+ *
+ * @return Our underlying Elm.Code object
  *
  * @ingroup Elm_Code_Widget
  */
@@ -45,6 +48,7 @@ EOAPI Elm_Code *elm_obj_code_widget_code_get(const Eo *obj);
  * @brief Set the font that this widget uses, the font should be a monospaced
  * scalable font. Passing NULL will load the default system monospaced font.
  *
+ * @param[in] obj The object.
  * @param[in] name The name of the font to load
  * @param[in] size The font size for the widget
  *
@@ -56,6 +60,7 @@ EOAPI void elm_obj_code_widget_font_set(Eo *obj, const char *name, int size);
  * @brief Get the font currently in use. The font name is a copy ad should be
  * freed once it is no longer needed
  *
+ * @param[in] obj The object.
  * @param[out] name The name of the font to load
  * @param[out] size The font size for the widget
  *
@@ -68,6 +73,8 @@ EOAPI void elm_obj_code_widget_font_get(const Eo *obj, const char **name, int *s
  * max of the number of columns to represent the longest line and the minimum
  * required to fill the visible widget width.
  *
+ * @param[in] obj The object.
+ *
  * @return The number of columns required to render the widget
  *
  * @ingroup Elm_Code_Widget
@@ -83,6 +90,7 @@ EOAPI unsigned int elm_obj_code_widget_columns_get(const Eo *obj);
  * the view will keep it's position relative to the top whereas 1.0 will scroll
  * downward as lines are added.
  *
+ * @param[in] obj The object.
  * @param[in] x The horizontal value of the scroller gravity - valid values are
  * 0.0 and 1.0
  * @param[in] y The vertical gravity of the widget's scroller - valid values
@@ -95,6 +103,7 @@ EOAPI void elm_obj_code_widget_gravity_set(Eo *obj, double x, double y);
 /**
  * @brief Get the current x and y gravity of the widget's scroller
  *
+ * @param[in] obj The object.
  * @param[out] x The horizontal value of the scroller gravity - valid values
  * are 0.0 and 1.0
  * @param[out] y The vertical gravity of the widget's scroller - valid values
@@ -107,6 +116,7 @@ EOAPI void elm_obj_code_widget_gravity_get(const Eo *obj, double *x, double *y);
 /**
  * @brief Set the policy for scrollbar visibility.
  *
+ * @param[in] obj The object.
  * @param[in] policy_h The horizontal scrollbar visibility policy
  * @param[in] policy_v The vertical scrollbar visibility policy
  *
@@ -117,6 +127,7 @@ EOAPI void elm_obj_code_widget_policy_set(Eo *obj, Elm_Scroller_Policy policy_h,
 /**
  * @brief Get the widget's policy for scrollbar visibility.
  *
+ * @param[in] obj The object.
  * @param[out] policy_h The horizontal scrollbar visibility policy
  * @param[out] policy_v The vertical scrollbar visibility policy
  *
@@ -130,6 +141,7 @@ EOAPI void elm_obj_code_widget_policy_get(const Eo *obj, Elm_Scroller_Policy *po
  *
  * Recommended value is between 2 and 8.
  *
+ * @param[in] obj The object.
  * @param[in] tabstop Maximum width of a tab character
  *
  * @ingroup Elm_Code_Widget
@@ -140,6 +152,8 @@ EOAPI void elm_obj_code_widget_tabstop_set(Eo *obj, unsigned int tabstop);
  * @brief Get the current width of a tab stop. This is used to determine where
  * characters after a tab should appear in the line.
  *
+ * @param[in] obj The object.
+ *
  * @return Maximum width of a tab character
  *
  * @ingroup Elm_Code_Widget
@@ -150,10 +164,11 @@ EOAPI unsigned int elm_obj_code_widget_tabstop_get(const Eo *obj);
  * @brief Set whether this widget allows editing
  *
  * If editable then the widget will allow user input to manipulate the
- * underlying Elm_Code_File of this Elm_Code instance. Any other
- * Elm_Code_Widget's connected to this Elm_Code will update to reflect the
+ * underlying Elm.Code_File of this Elm.Code instance. Any other
+ * Elm.Code_Widget's connected to this Elm.Code will update to reflect the
  * changes.
  *
+ * @param[in] obj The object.
  * @param[in] editable The editable state of the widget
  *
  * @ingroup Elm_Code_Widget
@@ -164,9 +179,11 @@ EOAPI void elm_obj_code_widget_editable_set(Eo *obj, Eina_Bool editable);
  * @brief Get the current editable state of this widget
  *
  * returns EINA_TRUE if the widget is editable, EINA_FALSE otherwise. If this
- * widget is not editable the underlying Elm_Code_File could still be
+ * widget is not editable the underlying Elm.Code_File could still be
  * manipulated by a different widget or the filesystem.
  *
+ * @param[in] obj The object.
+ *
  * @return The editable state of the widget
  *
  * @ingroup Elm_Code_Widget
@@ -179,6 +196,7 @@ EOAPI Eina_Bool elm_obj_code_widget_editable_get(const Eo *obj);
  * Passing EINA_TRUE will reserve a space for showing line numbers, EINA_FALSE
  * will turn this off.
  *
+ * @param[in] obj The object.
  * @param[in] line_numbers Whether or not line numbers (or their placeholder)
  * should be shown
  *
@@ -189,6 +207,8 @@ EOAPI void elm_obj_code_widget_line_numbers_set(Eo *obj, Eina_Bool line_numbers)
 /**
  * @brief Get the status of line number display for this widget.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether or not line numbers (or their placeholder) should be shown
  *
  * @ingroup Elm_Code_Widget
@@ -201,6 +221,7 @@ EOAPI Eina_Bool elm_obj_code_widget_line_numbers_get(const Eo *obj);
  * Passing a non-zero value will set which line width to mark with a vertical
  * line. Passing 0 will hide this marker.
  *
+ * @param[in] obj The object.
  * @param[in] line_width_marker Where to display a line width marker, if at all
  *
  * @ingroup Elm_Code_Widget
@@ -211,6 +232,8 @@ EOAPI void elm_obj_code_widget_line_width_marker_set(Eo *obj, unsigned int line_
  * @brief Get the position of the line width marker, any positive return
  * indicates where the marker appears.
  *
+ * @param[in] obj The object.
+ *
  * @return Where to display a line width marker, if at all
  *
  * @ingroup Elm_Code_Widget
@@ -220,6 +243,7 @@ EOAPI unsigned int elm_obj_code_widget_line_width_marker_get(const Eo *obj);
 /**
  * @brief Set whether white space should be shown.
  *
+ * @param[in] obj The object.
  * @param[in] show_whitespace Whether or not we show whitespace characters
  *
  * @ingroup Elm_Code_Widget
@@ -229,15 +253,41 @@ EOAPI void elm_obj_code_widget_show_whitespace_set(Eo *obj, Eina_Bool show_white
 /**
  * @brief Get whether or not white space will be visible.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether or not we show whitespace characters
  *
  * @ingroup Elm_Code_Widget
  */
 EOAPI Eina_Bool elm_obj_code_widget_show_whitespace_get(const Eo *obj);
 
+/**
+ * @brief Set an alpha color value for this widget (0 - 255) default is fully
+ * opaque (255).
+ *
+ * @param[in] obj The object.
+ * @param[in] alpha Alpha value
+ *
+ * @ingroup Elm_Code_Widget
+ */
+EOAPI void elm_obj_code_widget_alpha_set(Eo *obj, int alpha);
+
+/**
+ * @brief Set an alpha color value for this widget (0 - 255) default is fully
+ * opaque (255).
+ *
+ * @param[in] obj The object.
+ *
+ * @return Alpha value
+ *
+ * @ingroup Elm_Code_Widget
+ */
+EOAPI int elm_obj_code_widget_alpha_get(const Eo *obj);
+
 /**
  * @brief Set whether syntax highlighting should be use for this widget.
  *
+ * @param[in] obj The object.
  * @param[in] syntax_enabled Whether or not to enable syntax highlighting
  *
  * @ingroup Elm_Code_Widget
@@ -247,6 +297,8 @@ EOAPI void elm_obj_code_widget_syntax_enabled_set(Eo *obj, Eina_Bool syntax_enab
 /**
  * @brief Get this widget's enabled state for syntax highlighting.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether or not to enable syntax highlighting
  *
  * @ingroup Elm_Code_Widget
@@ -256,6 +308,7 @@ EOAPI Eina_Bool elm_obj_code_widget_syntax_enabled_get(const Eo *obj);
 /**
  * @brief Set whether space characters should be inserted instead of tabs.
  *
+ * @param[in] obj The object.
  * @param[in] tab_inserts_spaces @c true if we should insert space characters
  * instead of a tab when the Tab key is pressed
  *
@@ -266,6 +319,8 @@ EOAPI void elm_obj_code_widget_tab_inserts_spaces_set(Eo *obj, Eina_Bool tab_ins
 /**
  * @brief Get whether or not space characters will be inserted instead of tabs.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if we should insert space characters instead of a tab when
  * the Tab key is pressed
  *
@@ -276,6 +331,7 @@ EOAPI Eina_Bool elm_obj_code_widget_tab_inserts_spaces_get(const Eo *obj);
 /**
  * @brief Set the current location of the text cursor.
  *
+ * @param[in] obj The object.
  * @param[in] row The vertical position ov the cursur - the fist row is 1
  * @param[in] col The horizontal position of the cursor, starting from column 1
  *
@@ -286,6 +342,7 @@ EOAPI void elm_obj_code_widget_cursor_position_set(Eo *obj, unsigned int row, un
 /**
  * @brief Get the current x and y position of the widget's cursor.
  *
+ * @param[in] obj The object.
  * @param[out] row The vertical position ov the cursur - the fist row is 1
  * @param[out] col The horizontal position of the cursor, starting from column
  * 1
@@ -294,9 +351,16 @@ EOAPI void elm_obj_code_widget_cursor_position_set(Eo *obj, unsigned int row, un
  */
 EOAPI void elm_obj_code_widget_cursor_position_get(const Eo *obj, unsigned int *row, unsigned int *col);
 
+/** Update and refresh theme for widget.
+ *
+ * @ingroup Elm_Code_Widget
+ */
+EOAPI void elm_obj_code_widget_theme_refresh(Eo *obj);
+
 /**
  * @brief Refresh code line in widget
  *
+ * @param[in] obj The object.
  * @param[in] line The line to refresh.
  *
  * @ingroup Elm_Code_Widget
@@ -306,6 +370,7 @@ EOAPI void elm_obj_code_widget_line_refresh(Eo *obj, Elm_Code_Line *line);
 /**
  * @brief Check if the code line is currently visible
  *
+ * @param[in] obj The object.
  * @param[in] line The line to test for visibility.
  *
  * @return @c true if the line specified is currently visible within the scroll
@@ -318,6 +383,8 @@ EOAPI Eina_Bool elm_obj_code_widget_line_visible_get(Eo *obj, Elm_Code_Line *lin
 /**
  * @brief Get the number of code lines currently visible in the widget
  *
+ * @param[in] obj The object.
+ *
  * @return the number of lines currently visible in the widget.
  *
  * @ingroup Elm_Code_Widget
@@ -327,6 +394,7 @@ EOAPI unsigned int elm_obj_code_widget_lines_visible_get(Eo *obj);
 /**
  * @brief Get the row, col position for a given coordinate on the widget.
  *
+ * @param[in] obj The object.
  * @param[in] x The x coordinate in the widget
  * @param[in] y The y coordinate in the widget
  * @param[in] row The row for the coordinates
@@ -341,6 +409,7 @@ EOAPI Eina_Bool elm_obj_code_widget_position_at_coordinates_get(Eo *obj, int x,
 /**
  * @brief Get the geometry for the cell at the specified position.
  *
+ * @param[in] obj The object.
  * @param[in] row The row for the requested position
  * @param[in] col The column for the requested position
  * @param[in] x The x coordinate of the cell at specified position
@@ -357,6 +426,8 @@ EOAPI Eina_Bool elm_obj_code_widget_geometry_for_position_get(Eo *obj, unsigned
 /**
  * @brief Get the column width of the gutter
  *
+ * @param[in] obj The object.
+ *
  * @return The current column width of the gutter for the widget.
  *
  * @ingroup Elm_Code_Widget
@@ -366,6 +437,7 @@ EOAPI int elm_obj_code_widget_text_left_gutter_width_get(Eo *obj);
 /**
  * @brief Get text between given positions
  *
+ * @param[in] obj The object.
  * @param[in] start_line The line of the first character to get
  * @param[in] start_col The widget column of the first character to get
  * @param[in] end_line The line of the last character to get
@@ -381,6 +453,7 @@ EOAPI char *elm_obj_code_widget_text_between_positions_get(Eo *obj, unsigned int
  * @brief Insert the provided text at the cursor position. This will add the
  * operation to the widget's undo list.
  *
+ * @param[in] obj The object.
  * @param[in] text The text to insert
  *
  * @ingroup Elm_Code_Widget
@@ -390,6 +463,7 @@ EOAPI void elm_obj_code_widget_text_at_cursor_insert(Eo *obj, const char *text);
 /**
  * @brief Get text column width at given position
  *
+ * @param[in] obj The object.
  * @param[in] line Code line
  * @param[in] position Code position
  *
@@ -402,6 +476,7 @@ EOAPI unsigned int elm_obj_code_widget_line_text_column_width_to_position(Eo *ob
 /**
  * @brief Get text column width for code line
  *
+ * @param[in] obj The object.
  * @param[in] line Code line
  *
  * @return Text column width
@@ -413,6 +488,7 @@ EOAPI unsigned int elm_obj_code_widget_line_text_column_width_get(Eo *obj, Elm_C
 /**
  * @brief Get position from column
  *
+ * @param[in] obj The object.
  * @param[in] line Code line
  * @param[in] column Column
  *
@@ -425,6 +501,7 @@ EOAPI unsigned int elm_obj_code_widget_line_text_position_for_column_get(Eo *obj
 /**
  * @brief Get tabwidth for column
  *
+ * @param[in] obj The object.
  * @param[in] column Column
  *
  * @return Tabwidth
@@ -436,6 +513,7 @@ EOAPI unsigned int elm_obj_code_widget_text_tabwidth_at_column_get(Eo *obj, unsi
 /**
  * @brief Toggle the display of the line status widget
  *
+ * @param[in] obj The object.
  * @param[in] line Code line
  *
  * @ingroup Elm_Code_Widget
@@ -451,6 +529,8 @@ EOAPI void elm_obj_code_widget_undo(Eo *obj);
 /**
  * @brief Determine if there are any available undo operations
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if there are undo operations
  *
  * @ingroup Elm_Code_Widget
@@ -466,6 +546,8 @@ EOAPI void elm_obj_code_widget_redo(Eo *obj);
 /**
  * @brief Determine if there are any available redo operations
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if there are redo operations
  *
  * @ingroup Elm_Code_Widget
@@ -475,6 +557,7 @@ EOAPI Eina_Bool elm_obj_code_widget_can_redo_get(Eo *obj);
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_LINE_CLICKED;
 
 /** Called when text line was clicked
+ * @return Elm_Code_Line
  *
  * @ingroup Elm_Code_Widget
  */
@@ -483,19 +566,12 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_LINE_CLICKED
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED;
 
 /** Called when gutter was clicked
+ * @return Elm_Code_Line
  *
  * @ingroup Elm_Code_Widget
  */
 #define ELM_OBJ_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED (&(_ELM_OBJ_CODE_WIDGET_EVENT_LINE_GUTTER_CLICKED))
 
-EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED;
-
-/** Called when cursor changed
- *
- * @ingroup Elm_Code_Widget
- */
-#define ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED (&(_ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED))
-
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER;
 
 /** Called when object changed due to user interaction
@@ -504,9 +580,19 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER
  */
 #define ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER (&(_ELM_OBJ_CODE_WIDGET_EVENT_CHANGED_USER))
 
+EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED;
+
+/** Called when cursor changed
+ * @return Elm_Code_Widget *
+ *
+ * @ingroup Elm_Code_Widget
+ */
+#define ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED (&(_ELM_OBJ_CODE_WIDGET_EVENT_CURSOR_CHANGED))
+
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_START;
 
 /** Called when a selection is started
+ * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
@@ -515,6 +601,7 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_ST
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CHANGED;
 
 /** Called when selection changed
+ * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
@@ -523,6 +610,7 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CH
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CLEARED;
 
 /** Called when selection was cleared
+ * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
@@ -531,6 +619,7 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CL
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CUT;
 
 /** Called when a cut action is performed
+ * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
@@ -539,6 +628,7 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CU
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_COPY;
 
 /** Called when a copy action is performed
+ * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
@@ -547,6 +637,7 @@ EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_CO
 EWAPI extern const Efl_Event_Description _ELM_OBJ_CODE_WIDGET_EVENT_SELECTION_PASTE;
 
 /** Called when a paste action is performed
+ * @return Elm_Code_Widget *
  *
  * @ingroup Elm_Code_Widget
  */
