@@ -13,7 +13,7 @@ typedef Eo Elm_Toolbar_Item;
 
 /** Defines where to position the item in the toolbar.
  *
- * @ingroup Elm_Toolbar_Item
+ * @ingroup Elm
  */
 typedef enum
 {
@@ -30,7 +30,7 @@ typedef enum
 /** State of a Elm_Toolbar_Item. Can be created with
  * elm_toolbar_item_state_add() and removed with elm_toolbar_item_state_del().
  *
- * @ingroup Elm_Toolbar_Item
+ * @ingroup Elm
  */
 typedef struct _Elm_Toolbar_Item_State
 {
@@ -44,6 +44,68 @@ typedef struct _Elm_Toolbar_Item_State
 
 #endif
 
+/**
+ * @brief Get the item before this one in the widget's list of items.
+ *
+ * See also @ref elm_toolbar_item_next_get.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The item before the object in its parent's list. If there is no
+ * previous item or in case of error, @c null is returned.
+ *
+ * @ingroup Elm_Toolbar_Item
+ */
+EAPI Elm_Widget_Item *elm_toolbar_item_prev_get(const Elm_Toolbar_Item *obj);
+
+/**
+ * @brief Get the item after this one in the widget's list of items.
+ *
+ * See also @ref elm_toolbar_item_prev_get.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The item after the object in its parent's list. If there is no next
+ * item or in case of error, @c null is returned.
+ *
+ * @ingroup Elm_Toolbar_Item
+ */
+EAPI Elm_Widget_Item *elm_toolbar_item_next_get(const Elm_Toolbar_Item *obj);
+
+/**
+ * @brief Indicates whether this item is currently selected.
+ *
+ * Set the selected state of @c item.
+ *
+ * This sets the selected state of the given item @c it. @c true for selected,
+ * @c false for not selected.
+ *
+ * If a new item is selected the previously selected will be unselected.
+ * Previously selected item can be retrieved with
+ * @ref elm_toolbar_selected_item_get.
+ *
+ * Selected items will be highlighted.
+ *
+ * @param[in] obj The object.
+ * @param[in] selected The selection state.
+ *
+ * @ingroup Elm_Toolbar_Item
+ */
+EAPI void elm_toolbar_item_selected_set(Elm_Toolbar_Item *obj, Eina_Bool selected);
+
+/**
+ * @brief Indicates whether this item is currently selected.
+ *
+ * Get the selected state of this item.
+ *
+ * @param[in] obj The object.
+ *
+ * @return The selection state.
+ *
+ * @ingroup Elm_Toolbar_Item
+ */
+EAPI Eina_Bool elm_toolbar_item_selected_get(const Elm_Toolbar_Item *obj);
+
 /**
  * @brief Set the priority of a toolbar item.
  *
@@ -53,6 +115,7 @@ typedef struct _Elm_Toolbar_Item_State
  * added to a dynamically-created menu, while items with higher priority will
  * remain on the toolbar, with the same order they were added.
  *
+ * @param[in] obj The object.
  * @param[in] priority The @c item priority. The default is zero for set and 0
  * is returned on failure.
  *
@@ -63,6 +126,8 @@ EAPI void elm_toolbar_item_priority_set(Elm_Toolbar_Item *obj, int priority);
 /**
  * @brief Get the priority of a toolbar item.
  *
+ * @param[in] obj The object.
+ *
  * @return The @c item priority. The default is zero for set and 0 is returned
  * on failure.
  *
@@ -79,6 +144,7 @@ EAPI int elm_toolbar_item_priority_get(const Elm_Toolbar_Item *obj);
  *
  * @note This function does not accept relative icon path.
  *
+ * @param[in] obj The object.
  * @param[in] icon A string with icon name or the absolute path of an image
  * file.
  *
@@ -89,6 +155,8 @@ EAPI void elm_toolbar_item_icon_set(Elm_Toolbar_Item *obj, const char *icon);
 /**
  * @brief Get the string used to set the icon of @c item.
  *
+ * @param[in] obj The object.
+ *
  * @return A string with icon name or the absolute path of an image file.
  *
  * @ingroup Elm_Toolbar_Item
@@ -99,6 +167,8 @@ EAPI const char *elm_toolbar_item_icon_get(const Elm_Toolbar_Item *obj);
  * @brief Get the real Evas(Edje) object created to implement the view of a
  * given toolbar @c item.
  *
+ * @param[in] obj The object.
+ *
  * @return The base Edje object associated with @c it.
  *
  * @ingroup Elm_Toolbar_Item
@@ -111,6 +181,8 @@ EAPI Efl_Canvas_Object *elm_toolbar_item_object_get(const Elm_Toolbar_Item *obj)
  * See also @ref elm_toolbar_item_icon_set,
  * @ref elm_toolbar_item_icon_file_set, @ref elm_toolbar_item_icon_memfile_set.
  *
+ * @param[in] obj The object.
+ *
  * @return The icon object.
  *
  * @ingroup Elm_Toolbar_Item
@@ -125,6 +197,7 @@ EAPI Efl_Canvas_Object *elm_toolbar_item_icon_object_get(const Elm_Toolbar_Item
  * If set as separator it will display separator theme, so won't display icons
  * or label.
  *
+ * @param[in] obj The object.
  * @param[in] separator @c true if the item is a separator, @c false otherwise
  *
  * @ingroup Elm_Toolbar_Item
@@ -134,6 +207,8 @@ EAPI void elm_toolbar_item_separator_set(Elm_Toolbar_Item *obj, Eina_Bool separa
 /**
  * @brief Get a value whether item is a separator or not.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the item is a separator, @c false otherwise
  *
  * @ingroup Elm_Toolbar_Item
@@ -146,6 +221,8 @@ EAPI Eina_Bool elm_toolbar_item_separator_get(const Elm_Toolbar_Item *obj);
  * If @c item wasn't set as menu item with @ref elm_toolbar_item_menu_set, this
  * function will set it.
  *
+ * @param[in] obj The object.
+ *
  * @return Item's menu object or @c null on failure.
  *
  * @ingroup Elm_Toolbar_Item
@@ -159,6 +236,7 @@ EAPI Efl_Canvas_Object *elm_toolbar_item_menu_get(const Elm_Toolbar_Item *obj);
  * icon and label will be used. It's the behavior as @ref
  * elm_toolbar_item_state_unset.
  *
+ * @param[in] obj The object.
  * @param[in] state Item state
  *
  * @return @c true on success, @c false otherwise
@@ -170,6 +248,8 @@ EAPI Eina_Bool elm_toolbar_item_state_set(Elm_Toolbar_Item *obj, Elm_Toolbar_Ite
 /**
  * @brief Get the current state of @c it.
  *
+ * @param[in] obj The object.
+ *
  * @return Item state
  *
  * @ingroup Elm_Toolbar_Item
@@ -182,6 +262,7 @@ EAPI Elm_Toolbar_Item_State *elm_toolbar_item_state_get(const Elm_Toolbar_Item *
  * @note The icon image set by this function can be changed by
  * @ref elm_toolbar_item_icon_set.
  *
+ * @param[in] obj The object.
  * @param[in] img The binary data that will be used as an image.
  * @param[in] size The size of binary data @c img.
  * @param[in] format Optional format of @c img to pass to the image loader.
@@ -200,6 +281,7 @@ EAPI Eina_Bool elm_toolbar_item_icon_memfile_set(Elm_Toolbar_Item *obj, const vo
  * @note The icon image set by this function can be changed by
  * elm_toolbar_item_icon_set().
  *
+ * @param[in] obj The object.
  * @param[in] file The file that contains the image.
  * @param[in] key Optional key of @c img to pass to the image loader (eg. if
  * @c img is an edje file).
@@ -220,6 +302,7 @@ EAPI Eina_Bool elm_toolbar_item_icon_file_set(Elm_Toolbar_Item *obj, const char
  * States created with this function can be removed with
  * @ref elm_toolbar_item_state_del.
  *
+ * @param[in] obj The object.
  * @param[in] icon A string with icon name or the absolute path of an image
  * file.
  * @param[in] label The label of the new state.
@@ -236,6 +319,7 @@ EAPI Elm_Toolbar_Item_State *elm_toolbar_item_state_add(Elm_Toolbar_Item *obj, c
 /**
  * @brief Delete a previously added state to @c item.
  *
+ * @param[in] obj The object.
  * @param[in] state The state to be deleted.
  *
  * @return @c true on success or @c false on failure.
@@ -249,6 +333,8 @@ EAPI Eina_Bool elm_toolbar_item_state_del(Elm_Toolbar_Item *obj, Elm_Toolbar_Ite
  *
  * If last state is selected, this function will return first state.
  *
+ * @param[in] obj The object.
+ *
  * @return The state after current state, or @c null on failure.
  *
  * @ingroup Elm_Toolbar_Item
@@ -260,6 +346,8 @@ EAPI Elm_Toolbar_Item_State *elm_toolbar_item_state_next(Elm_Toolbar_Item *obj);
  *
  * If first state is selected, this function will return last state.
  *
+ * @param[in] obj The object.
+ *
  * @return The state before current state, or @c null on failure.
  *
  * @ingroup Elm_Toolbar_Item
@@ -269,6 +357,7 @@ EAPI Elm_Toolbar_Item_State *elm_toolbar_item_state_prev(Elm_Toolbar_Item *obj);
 /**
  * @brief Show a specific item, when the toolbar can be scrolled.
  *
+ * @param[in] obj The object.
  * @param[in] scrollto The position the item should appear at.
  *
  * @since 1.8
@@ -281,6 +370,7 @@ EAPI void elm_toolbar_item_show(Elm_Toolbar_Item *obj, Elm_Toolbar_Item_Scrollto
  * @brief Show a specific item with scroll animation, when the toolbar can be
  * scrolled.
  *
+ * @param[in] obj The object.
  * @param[in] scrollto The position the item should appear at.
  *
  * @since 1.8
@@ -301,6 +391,7 @@ EAPI void elm_toolbar_item_bring_in(Elm_Toolbar_Item *obj, Elm_Toolbar_Item_Scro
  * So, items to be displayed in this item's menu should be added with @ref
  * elm_menu_item_add.
  *
+ * @param[in] obj The object.
  * @param[in] menu If @c true, @c item will opens a menu when selected.
  *
  * @ingroup Elm_Toolbar_Item
