@@ -19,17 +19,17 @@ typedef Eo Efl_Canvas_Polygon;
  */
 #define EFL_CANVAS_POLYGON_CLASS efl_canvas_polygon_class_get()
 
-EWAPI const Eo_Class *efl_canvas_polygon_class_get(void);
+EWAPI const Efl_Class *efl_canvas_polygon_class_get(void);
 
 /**
  * @brief Adds the given point to the given evas polygon object.
  *
- * @param[in] x The X coordinate of the given point.
- * @param[in] y The Y coordinate of the given point.
+ * @param[in] obj The object.
+ * @param[in] pos A point coordinate.
  *
  * @ingroup Efl_Canvas_Polygon
  */
-EOAPI void efl_canvas_polygon_point_add(Eo *obj, Evas_Coord x, Evas_Coord y);
+EOAPI void efl_canvas_polygon_point_add(Eo *obj, Eina_Position2D pos);
 
 /** Removes all of the points from the given evas polygon object.
  *
@@ -37,5 +37,4 @@ EOAPI void efl_canvas_polygon_point_add(Eo *obj, Evas_Coord x, Evas_Coord y);
  */
 EOAPI void efl_canvas_polygon_points_clear(Eo *obj);
 
-
 #endif
